@@ -3,7 +3,7 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import appNameInjectable from "../../app-paths/app-name/app-name.injectable";
+import appNameInjectable from "../../../common/vars/app-name.injectable";
 import { beforeElectronIsReadyInjectionToken } from "../../start-main-application/runnable-tokens/before-electron-is-ready-injection-token";
 import electronAppInjectable from "../electron-app.injectable";
 
