@@ -5,39 +5,34 @@
 
 import fs from "fs";
 import * as yaml from "js-yaml";
-import logger from "../logger";
 import type { RepoHelmChartList } from "../../common/k8s-api/endpoints/helm-charts.api";
 import { iter, put, sortCharts } from "../../common/utils";
 import { execHelm } from "./exec";
 import type { SetRequired } from "type-fest";
 import { assert } from "console";
 import type { HelmRepo } from "../../common/helm/helm-repo";
-
-interface ChartCacheEntry {
-  data: string; // serialized JSON
-  mtimeMs: number;
-}
+import type { HelmChartManagerCache } from "./helm-chart-manager-cache.injectable";
+import type { Logger } from "../../common/logger";
 
 export interface HelmCacheFile {
   apiVersion: string;
   entries: RepoHelmChartList;
 }
 
-export class HelmChartManager {
-  static readonly #cache = new Map<string, ChartCacheEntry>();
+interface Dependencies {
+  cache: HelmChartManagerCache;
+  logger: Logger;
+}
 
+export class HelmChartManager {
   protected readonly repo: SetRequired<HelmRepo, "cacheFilePath">;
 
-  private constructor(repo: HelmRepo) {
+  constructor(repo: HelmRepo, private dependencies: Dependencies) {
     assert(repo.cacheFilePath, "CacheFilePath must be provided on the helm repo");
 
     this.repo = repo as SetRequired<HelmRepo, "cacheFilePath">;
   }
 
-  static forRepo(repo: HelmRepo) {
-    return new this(repo);
-  }
-
   public async chartVersions(name: string) {
     const charts = await this.charts();
 
@@ -48,7 +43,7 @@ export class HelmChartManager {
     try {
       return await this.cachedYaml();
     } catch(error) {
-      logger.error("HELM-CHART-MANAGER]: failed to list charts", { error });
+      this.dependencies.logger.error("HELM-CHART-MANAGER]: failed to list charts", { error });
 
       return {};
     }
@@ -84,7 +79,7 @@ export class HelmChartManager {
     const normalized = normalizeHelmCharts(this.repo.name, data.entries);
 
     return put(
-      HelmChartManager.#cache,
+      this.dependencies.cache,
       this.repo.name,
       {
         data: JSON.stringify(normalized),
@@ -94,7 +89,7 @@ export class HelmChartManager {
   }
 
   protected async cachedYaml(): Promise<RepoHelmChartList> {
-    let cacheEntry = HelmChartManager.#cache.get(this.repo.name);
+    let cacheEntry = this.dependencies.cache.get(this.repo.name);
 
     if (!cacheEntry) {
       cacheEntry = await this.updateYamlCache();
