@@ -3,14 +3,16 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { HelmChartManager } from "../helm-chart-manager";
 import getActiveHelmRepositoryInjectable from "../repositories/get-active-helm-repository.injectable";
+import type { HelmRepo } from "../../../common/helm/helm-repo";
+import helmChartManagerInjectable from "../helm-chart-manager.injectable";
 
 const getHelmChartInjectable = getInjectable({
   id: "get-helm-chart",
 
   instantiate: (di) => {
     const getActiveHelmRepository = di.inject(getActiveHelmRepositoryInjectable);
+    const getChartManager = (repo: HelmRepo) => di.inject(helmChartManagerInjectable, repo);
 
     return async (repoName: string, chartName: string, version = "") => {
       const repo = await getActiveHelmRepository(repoName);
@@ -19,7 +21,7 @@ const getHelmChartInjectable = getInjectable({
         return undefined;
       }
 
-      const chartManager = HelmChartManager.forRepo(repo);
+      const chartManager = getChartManager(repo);
 
       return {
         readme: await chartManager.getReadme(chartName, version),
