@@ -4,6 +4,7 @@
  */
 import { pipeline } from "@ogre-tools/fp";
 import { getInjectable, getInjectionToken } from "@ogre-tools/injectable";
+import { computedInjectManyInjectable } from "@ogre-tools/injectable-extension-for-mobx";
 import { filter, orderBy } from "lodash/fp";
 import type { IComputedValue } from "mobx";
 import { computed } from "mobx";
@@ -20,19 +21,24 @@ export interface PreferenceNavigationItem {
   isVisible: IComputedValue<boolean>;
   navigate: () => void;
   orderNumber: number;
+  parent: string;
 }
 
 const preferenceNavigationItemsInjectable = getInjectable({
   id: "preference-navigation-items",
 
-  instantiate: (di) =>
-    computed((): PreferenceNavigationItem[] =>
+  instantiate: (di) => {
+    const computedInjectMany = di.inject(computedInjectManyInjectable);
+    const navigationItems = computedInjectMany(preferenceNavigationItemInjectionToken);
+
+    return computed((): PreferenceNavigationItem[] =>
       pipeline(
-        di.injectMany(preferenceNavigationItemInjectionToken),
+        navigationItems.get(),
         filter((item) => !!item.isVisible.get()),
         (items) => orderBy([(item) => item.orderNumber], ["asc"], items),
       ),
-    ),
+    );
+  },
 });
 
 export default preferenceNavigationItemsInjectable;
