@@ -11,7 +11,7 @@ export interface WelcomeBannerRegistration {
   /**
    * The banner component to be shown on the welcome screen.
    */
-  Banner?: React.ComponentType;
+  Banner: React.ComponentType;
   /**
    * The banner width in px.
    */
