@@ -8,79 +8,25 @@ import { observer } from "mobx-react";
 import type { Cluster } from "../../../../common/cluster/cluster";
 import { Input } from "../../input";
 import { SubTitle } from "../../layout/sub-title";
-import { stat } from "fs/promises";
-import { Notifications } from "../../notifications";
-import { isErrnoException, resolveTilde } from "../../../utils";
+import type { ShowNotification } from "../../notifications";
+import { resolveTilde } from "../../../utils";
 import { Icon } from "../../icon";
 import { PathPicker } from "../../path-picker";
 import { isWindows } from "../../../../common/vars";
-import type { Stats } from "fs";
-import logger from "../../../../common/logger";
-import { lowerFirst } from "lodash";
+import { withInjectables } from "@ogre-tools/injectable-react";
+import showErrorNotificationInjectable from "../../notifications/show-error-notification.injectable";
+import type { ValidateDirectory } from "../../../../common/fs/validate-directory.injectable";
+import validateDirectoryInjectable from "../../../../common/fs/validate-directory.injectable";
 
 export interface ClusterLocalTerminalSettingProps {
   cluster: Cluster;
 }
-
-function getUserReadableFileType(stats: Stats): string {
-  if (stats.isFile()) {
-    return "a file";
-  }
-
-  if (stats.isFIFO()) {
-    return "a pipe";
-  }
-
-  if (stats.isSocket()) {
-    return "a socket";
-  }
-
-  if (stats.isBlockDevice()) {
-    return "a block device";
-  }
-
-  if (stats.isCharacterDevice()) {
-    return "a character device";
-  }
-
-  return "an unknown file type";
+interface Dependencies {
+  showErrorNotification: ShowNotification;
+  validateDirectory: ValidateDirectory;
 }
 
-/**
- * Validate that `dir` currently points to a directory. If so return `false`.
- * Otherwise, return a user readable error message string for displaying.
- * @param dir The path to be validated
- */
-async function validateDirectory(dir: string): Promise<string | false> {
-  try {
-    const stats = await stat(dir);
-
-    if (stats.isDirectory()) {
-      return false;
-    }
-
-    return `the provided path is ${getUserReadableFileType(stats)} and not a directory.`;
-  } catch (error) {
-    switch (isErrnoException(error) ? error.code : undefined) {
-      case "ENOENT":
-        return `the provided path does not exist.`;
-      case "EACCES":
-        return `search permissions is denied for one of the directories in the prefix of the provided path.`;
-      case "ELOOP":
-        return `the provided path is a sym-link which points to a chain of sym-links that is too long to resolve. Perhaps it is cyclic.`;
-      case "ENAMETOOLONG":
-        return `the pathname is too long to be used.`;
-      case "ENOTDIR":
-        return `a prefix of the provided path is not a directory.`;
-      default:
-        logger.warn(`[CLUSTER-LOCAL-TERMINAL-SETTINGS]: unexpected error in validateDirectory for resolved path=${dir}`, error);
-
-        return error ? lowerFirst(String(error)) : "of an unknown error, please try again.";
-    }
-  }
-}
-
-export const ClusterLocalTerminalSetting = observer(({ cluster }: ClusterLocalTerminalSettingProps) => {
+const NonInjectedClusterLocalTerminalSetting = observer(({ cluster, showErrorNotification, validateDirectory }: Dependencies & ClusterLocalTerminalSettingProps) => {
   if (!cluster) {
     return null;
   }
@@ -109,15 +55,15 @@ export const ClusterLocalTerminalSetting = observer(({ cluster }: ClusterLocalTe
       cluster.preferences.terminalCWD = undefined;
     } else {
       const dir = resolveTilde(directory);
-      const errorMessage = await validateDirectory(dir);
+      const result = await validateDirectory(dir);
 
-      if (errorMessage) {
-        Notifications.error(
+      if (!result.callWasSuccessful) {
+        showErrorNotification(
           <>
             <b>Terminal Working Directory</b>
             <p>
               {"Your changes were not saved because "}
-              {errorMessage}
+              {result.error}
             </p>
           </>,
         );
@@ -203,3 +149,16 @@ export const ClusterLocalTerminalSetting = observer(({ cluster }: ClusterLocalTe
     </>
   );
 });
+
+export const ClusterLocalTerminalSetting = withInjectables<Dependencies, ClusterLocalTerminalSettingProps>(
+  NonInjectedClusterLocalTerminalSetting,
+
+  {
+    getProps: (di, props) => ({
+      showErrorNotification: di.inject(showErrorNotificationInjectable),
+      validateDirectory: di.inject(validateDirectoryInjectable),
+      ...props,
+    }),
+  },
+);
+
