@@ -4,11 +4,17 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { storesAndApisCanBeCreatedInjectionToken } from "../common/k8s-api/stores-apis-can-be-created.token";
-import { getClusterIdFromHost } from "./utils";
+import hostedClusterIdInjectable from "./cluster-frame-context/hosted-cluster-id.injectable";
 
 const storesAndApisCanBeCreatedInjectable = getInjectable({
   id: "create-stores-and-apis",
-  instantiate: () => Boolean(getClusterIdFromHost(location.host)),
+
+  instantiate: (di) => {
+    const hostedClusterId = di.inject(hostedClusterIdInjectable);
+
+    return !!hostedClusterId;
+  },
+
   injectionToken: storesAndApisCanBeCreatedInjectionToken,
 });
 
